<?php 
/*
Plugin Name: MSA Limit File Upload Size
Plugin URI: https://blog.monteamador.com/limiting-media-upload-file-sizes-in-wordpress/
Description: Activating this plugin allows to control upload file size limits set for all media uploads. By default, file size limits are 2MB for site administrators and 750KB for all other users capabilities. If you need to increase the file size you can disable this plugin or edit the plugin file's '$limit' variable.
Version: 1.0
Author: Monte Amador
Author URI: https://monteamador.com
/**
 * Set file size limits for Admins and non-admins.
 *
 * @param string $size Upload size limit (in bytes).
 * @return int (maybe) Filtered size limit.
 */

function file_size_upload_limit_filter( $size ) {

   if( current_user_can( 'manage_options' ) ) {
      // Set limit to 2MB (2000KB) for Admins
      // Editing this number allows for Admin adjustments.
      $limit = 1500;

   } else {
      // Set limit to 750KB for non-admins
      // Editing this number allows for non-Admin adjustments.
      $limit = 750;
   }
   
   $size = 1024 * $limit;
   return $size;
}
add_filter( 'upload_size_limit', 'file_size_upload_limit_filter', 20 );


// DO NOT DELETE ?>